@@ -6,10 +6,11 @@ sha_new = lambda *args, **kwargs: hashlib.new("sha1", *args, **kwargs)
 
 import socket
 import ssl
-
 import struct
 import sys
 import os
+import stat
+
 try:
     from ConfigParser import RawConfigParser
 except ImportError:
@@ -181,7 +182,10 @@ class Connection(object):
             if sys.platform.startswith("win"):
                 read_default_file = "c:\\my.ini"
             else:
-                read_default_file = "/etc/my.cnf"
+                for f in ('~/.my.cnf', '/etc/my.cnf', '/etc/mysql/my.cnf'):
+                    if os.path.isfile(os.path.expanduser(f)):
+                        read_default_file = f
+                        break
 
         if read_default_file:
             if not read_default_group:
@@ -204,6 +208,16 @@ class Connection(object):
             port = _config("port", port)
             charset = _config("default-character-set", charset)
 
+        if (host == 'localhost' and port == 3306
+            and not sys.platform.startswith('win')
+            and (unix_socket is None or not os.path.exists(unix_socket))):
+            for f in ('/var/lib/mysql/mysql.sock',
+                    '/var/run/mysql/mysql.sock',
+                    '/var/run/mysql.sock',
+                    '/var/mysql/mysql.sock'):
+                if os.path.exists(f) and stat.S_ISSOCK(os.stat(f).st_mode):
+                    unix_socket = f
+                    break
         self.host = host
         self.port = port
         self.user = user or DEFAULT_USER
