@@ -16,18 +16,6 @@ ESCAPE_REGEX = re.compile(r"[\0\n\r\032\'\"\\]")
 ESCAPE_MAP = {'\0': '\\0', '\n': '\\n', '\r': '\\r', '\032': '\\Z',
               '\'': '\\\'', '"': '\\"', '\\': '\\\\'}
 
-def escape_item(val, charset):
-    if type(val) in [tuple, list, set]:
-        return escape_sequence(val, charset)
-    if type(val) is dict:
-        return escape_dict(val, charset)
-    encoder = encoders[type(val)]
-    val = encoder(val)
-    if type(val) is str:
-        return val
-    val = val.encode(charset)
-    return val
-
 def escape_dict(val, charset):
     n = {}
     for k, v in val.items():
@@ -62,6 +50,8 @@ def escape_string(value):
             lambda match: ESCAPE_MAP.get(match.group(0)), value))
 
 def escape_bytes(value):
+    if len(value)==0:
+        return "''"
     return '0x' + ''.join([('0'+hex(c)[2:])[-2:] for c in value])
 
 def escape_unicode(value):
@@ -85,10 +75,11 @@ def escape_time(obj):
     return escape_string(s)
 
 def escape_datetime(obj):
-    return escape_string(obj.strftime("%Y-%m-%d %H:%M:%S"))
+    return escape_string("%04d-%02d-%02d %02d:%02d:%02d" % (
+            obj.year, obj.month, obj.day, obj.hour, obj.minute, obj.second))
 
 def escape_date(obj):
-    return escape_string(obj.strftime("%Y-%m-%d"))
+    return escape_string("%04d-%02d-%02d" % (obj.year, obj.month, obj.day))
 
 def escape_struct_time(obj):
     return escape_datetime(datetime.datetime(*obj[:6]))
@@ -302,30 +293,6 @@ def convert_decimal(data, charset=None, field=None, use_unicode=None):
     data = data.decode(charset)
     return Decimal(data)
 
-encoders = {
-        bool: escape_bool,
-        int: escape_int,
-        float: escape_float,
-        Decimal: escape_decimal,
-        str: escape_string,
-        tuple: escape_sequence,
-        list:escape_sequence,
-        set:escape_sequence,
-        dict:escape_dict,
-        type(None):escape_None,
-        datetime.date: escape_date,
-        datetime.datetime : escape_datetime,
-        datetime.timedelta : escape_timedelta,
-        datetime.time : escape_time,
-        time.struct_time : escape_struct_time,
-        }
-
-if PYTHON3:
-    encoders[bytes] = escape_bytes
-else:
-    encoders[unicode] = escape_unicode
-    encoders[long] = escape_long
-
 decoders = {
         FIELD_TYPE.BIT: convert_bit,
         FIELD_TYPE.TINY: convert_int,
@@ -354,3 +321,40 @@ decoders = {
         FIELD_TYPE.VARCHAR: convert_characters,
         }
 
+encoders = {
+        bool: escape_bool,
+        int: escape_int,
+        float: escape_float,
+        Decimal: escape_decimal,
+        str: escape_string,
+        tuple: escape_sequence,
+        list:escape_sequence,
+        set:escape_sequence,
+        dict:escape_dict,
+        type(None):escape_None,
+        datetime.date: escape_date,
+        datetime.datetime : escape_datetime,
+        datetime.timedelta : escape_timedelta,
+        datetime.time : escape_time,
+        time.struct_time : escape_struct_time,
+        }
+
+if PYTHON3:
+    encoders[bytes] = escape_bytes
+else:
+    encoders[unicode] = escape_unicode
+    encoders[long] = escape_long
+
+
+def escape_item(val, charset, encoders=encoders):
+    if type(val) in [tuple, list, set]:
+        return escape_sequence(val, charset)
+    if type(val) is dict:
+        return escape_dict(val, charset)
+    encoder = encoders[type(val)]
+    val = encoder(val)
+    if type(val) is str:
+        return val
+    val = val.encode(charset)
+    return val
+
